@@ -28,26 +28,34 @@ XmlDocument::XmlDocument (const File& file)  : inputSource (new FileInputSource
 
 XmlDocument::~XmlDocument() {}
 
-XmlElement* XmlDocument::parse (const File& file)
+std::unique_ptr<XmlElement> XmlDocument::parse (const File& file)
 {
-    XmlDocument doc (file);
-    return doc.getDocumentElement();
+    return XmlDocument (file).getDocumentElement();
 }
 
-XmlElement* XmlDocument::parse (const String& xmlData)
+std::unique_ptr<XmlElement> XmlDocument::parse (const String& textToParse)
 {
-    XmlDocument doc (xmlData);
-    return doc.getDocumentElement();
+    return XmlDocument (textToParse).getDocumentElement();
 }
 
 std::unique_ptr<XmlElement> parseXML (const String& textToParse)
 {
-    return std::unique_ptr<XmlElement> (XmlDocument::parse (textToParse));
+    return XmlDocument (textToParse).getDocumentElement();
 }
 
-std::unique_ptr<XmlElement> parseXML (const File& fileToParse)
+std::unique_ptr<XmlElement> parseXML (const File& file)
 {
-    return std::unique_ptr<XmlElement> (XmlDocument::parse (fileToParse));
+    return XmlDocument (file).getDocumentElement();
+}
+
+std::unique_ptr<XmlElement> parseXMLIfTagMatches (const String& textToParse, StringRef requiredTag)
+{
+    return XmlDocument (textToParse).getDocumentElementIfTagMatches (requiredTag);
+}
+
+std::unique_ptr<XmlElement> parseXMLIfTagMatches (const File& file, StringRef requiredTag)
+{
+    return XmlDocument (file).getDocumentElementIfTagMatches (requiredTag);
 }
 
 void XmlDocument::setInputSource (InputSource* newSource) noexcept
@@ -72,7 +80,7 @@ namespace XmlIdentifierChars
     {
         static const uint32 legalChars[] = { 0, 0x7ff6000, 0x87fffffe, 0x7fffffe, 0 };
 
-        return ((int) c < (int) numElementsInArray (legalChars) * 32) ? ((legalChars [c >> 5] & (1 << (c & 31))) != 0)
+        return ((int) c < (int) numElementsInArray (legalChars) * 32) ? ((legalChars [c >> 5] & (uint32) (1 << (c & 31))) != 0)
                                                                       : isIdentifierCharSlow (c);
     }
 
@@ -99,7 +107,7 @@ namespace XmlIdentifierChars
     }
 }
 
-XmlElement* XmlDocument::getDocumentElement (const bool onlyReadOuterDocumentElement)
+std::unique_ptr<XmlElement> XmlDocument::getDocumentElement (const bool onlyReadOuterDocumentElement)
 {
     if (originalText.isEmpty() && inputSource != nullptr)
     {
@@ -139,6 +147,15 @@ XmlElement* XmlDocument::getDocumentElement (const bool onlyReadOuterDocumentEle
     return parseDocumentElement (originalText.getCharPointer(), onlyReadOuterDocumentElement);
 }
 
+std::unique_ptr<XmlElement> XmlDocument::getDocumentElementIfTagMatches (StringRef requiredTag)
+{
+    if (auto xml = getDocumentElement (true))
+        if (xml->hasTagName (requiredTag))
+            return getDocumentElement (false);
+
+    return {};
+}
+
 const String& XmlDocument::getLastParseError() const noexcept
 {
     return lastError;
@@ -176,8 +193,8 @@ juce_wchar XmlDocument::readNextChar() noexcept
     return c;
 }
 
-XmlElement* XmlDocument::parseDocumentElement (String::CharPointerType textToParse,
-                                               const bool onlyReadOuterDocumentElement)
+std::unique_ptr<XmlElement> XmlDocument::parseDocumentElement (String::CharPointerType textToParse,
+                                                               bool onlyReadOuterDocumentElement)
 {
     input = textToParse;
     errorOccurred = false;
@@ -202,10 +219,10 @@ XmlElement* XmlDocument::parseDocumentElement (String::CharPointerType textToPar
         std::unique_ptr<XmlElement> result (readNextElement (! onlyReadOuterDocumentElement));
 
         if (! errorOccurred)
-            return result.release();
+            return result;
     }
 
-    return nullptr;
+    return {};
 }
 
 bool XmlDocument::parseHeader()
